@@ -304,25 +304,15 @@ def list_outputs(sway=False, silent=False):
             print("'wlr-randr' command not found, terminating")
             sys.exit(1)
 
-    # We used to assign Gdk.Monitor to output on the basis of x and y coordinates, but it no longer works,
-    # starting from gtk3-1:3.24.42: all monitors have x=0, y=0. This is most likely a bug, but from now on
-    # we must rely on gdk monitors order. Hope it's going to work.
-    # monitors = []
-
     display = Gdk.Display.get_default()
     for i in range(display.get_n_monitors()):
         monitor = display.get_monitor(i)
         geometry = monitor.get_geometry()
-        # monitors.append(monitor)
         for key in outputs_dict:
-            if outputs_dict[key]["x"] == geometry.x and outputs_dict[key]["y"] == geometry.y and outputs_dict[key][
-                "width"] == geometry.width and outputs_dict[key]["height"] == geometry.height:
+            if outputs_dict[key]["x"] == geometry.x and outputs_dict[key]["y"] == geometry.y:
                 outputs_dict[key]["monitor"] = monitor
                 break
 
-    # for key, monitor in zip(outputs_dict.keys(), monitors):
-    #     outputs_dict[key]["monitor"] = monitor
-
     # map monitor descriptions to output names
     mon_desc2output_name = {}
     for key in outputs_dict:
@@ -936,12 +926,7 @@ def cmd_through_compositor(cmd):
         elif os.getenv("HYPRLAND_INSTANCE_SIGNATURE"):
             cmd = f'hyprctl dispatch exec "{cmd}"'
         elif os.getenv("NIRI_SOCKET"):
-            parts = cmd.split()
-            quoted = []
-            for part in parts:
-                quoted.append(f'"{part}"')
-            _string = " ".join(quoted)
-            cmd = f'niri msg action spawn -- {_string}'
+            cmd = f'niri msg action spawn -- {cmd}'
     return cmd
 
 
